@@ -1,14 +1,15 @@
-from collections import namedtuple
 import re
 import sys
+from collections import namedtuple
 
 from .connection import connect, Connection
 from .cursor import Cursor
 from .pool import create_pool, Pool
 
-__all__ = ('connect', 'create_pool', 'Connectiion', 'Cursor', 'Pool')
 
-__version__ = '0.2.0'
+__all__ = ('connect', 'create_pool', 'Connection', 'Cursor', 'Pool')
+
+__version__ = '0.2.1'
 
 version = __version__ + ' , Python ' + sys.version
 
