@@ -117,13 +117,22 @@ class Connection:
     def cursor(self, name=None, cursor_factory=None,
                scrollable=None, withhold=False):
         """XXX"""
+        impl = yield from self._cursor(name=name,
+                                       cursor_factory=cursor_factory,
+                                       scrollable=scrollable,
+                                       withhold=withhold)
+        return Cursor(self, impl)
+
+    @asyncio.coroutine
+    def _cursor(self, name=None, cursor_factory=None,
+                scrollable=None, withhold=False):
         if cursor_factory is None:
             impl = self._conn.cursor(name=name,
                                      scrollable=scrollable, withhold=withhold)
         else:
             impl = self._conn.cursor(name=name, cursor_factory=cursor_factory,
                                      scrollable=scrollable, withhold=withhold)
-        return Cursor(self, impl)
+        return impl
 
     @asyncio.coroutine
     def close(self):
